==> openjdk-23_23~34ea.orig.tar.xz: openjdk-23-23~34ea/src/java.base/windows/classes/sun/nio/ch/FileKey.java <==
/*
 * Copyright (c) 2005, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package sun.nio.ch;

import java.io.FileDescriptor;
import java.io.IOException;

/*
 * Represents a key to a specific file on Windows
 */
public class FileKey {

    private int dwVolumeSerialNumber;
    private int nFileIndexHigh;
    private int nFileIndexLow;

    private FileKey() { }

    public static FileKey create(FileDescriptor fd) throws IOException {
        FileKey fk = new FileKey();
        fk.init(fd);
        return fk;
    }

    @Override
    public int hashCode() {
        return dwVolumeSerialNumber + nFileIndexHigh + nFileIndexLow;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this)
            return true;
        return obj instanceof FileKey other
                && this.dwVolumeSerialNumber == other.dwVolumeSerialNumber
                && this.nFileIndexHigh == other.nFileIndexHigh
                && this.nFileIndexLow == other.nFileIndexLow;
    }

    private native void init(FileDescriptor fd) throws IOException;
    private static native void initIDs();

    static {
        IOUtil.load();
        initIDs();
    }
}

==> openjdk-25_25~10ea.orig.tar.xz: openjdk-25-25~10ea/src/java.base/windows/classes/sun/nio/ch/FileKey.java <==
/*
 * Copyright (c) 2005, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package sun.nio.ch;

import java.io.FileDescriptor;
import java.io.IOException;

/*
 * Represents a key to a specific file on Windows
 */
public class FileKey {

    private final int dwVolumeSerialNumber;
    private final int nFileIndexHigh;
    private final int nFileIndexLow;

    private FileKey(int dwVolumeSerialNumber, int nFileIndexHigh,
        int nFileIndexLow) {
        this.dwVolumeSerialNumber = dwVolumeSerialNumber;
        this.nFileIndexHigh = nFileIndexHigh;
        this.nFileIndexLow = nFileIndexLow;
    }

    public static FileKey create(FileDescriptor fd) throws IOException {
        int finfo[] = new int[3];
        init(fd, finfo);
        return new FileKey(finfo[0], finfo[1], finfo[2]);
    }

    @Override
    public int hashCode() {
        return dwVolumeSerialNumber + nFileIndexHigh + nFileIndexLow;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this)
            return true;
        return obj instanceof FileKey other
                && this.dwVolumeSerialNumber == other.dwVolumeSerialNumber
                && this.nFileIndexHigh == other.nFileIndexHigh
                && this.nFileIndexLow == other.nFileIndexLow;
    }

    private static native void init(FileDescriptor fd, int[] finfo)
        throws IOException;

    static {
        IOUtil.load();
    }
}
